@@ -12,7 +12,7 @@ use Scalar::Util qw(weaken);
 use strict;
 use vars qw($Debug $VERSION $HashId);
 
-$VERSION = '1.252';
+$VERSION = '1.260';
 
 $Debug = $Parallel::Forker::Debug;
 $HashId = 0;
@@ -29,6 +29,7 @@ sub _new {
 	_ref_count => 0,        # number of people depending on us
 	pid => undef,		# Pid # running as, undef=not running
 	run_after => [],	# Process objects that are prereqs
+	run_pre_start => sub {},
 	run_on_start => sub {confess "%Error: No run_on_start defined\n";},
 	run_on_finish => sub {my ($procref,$status) = @_;},	# Routine taking child and exit status
 	@_
@@ -226,6 +227,7 @@ sub run {
     print "  FrkProc $self->{name} $self->{_state} -> running\n" if $Debug;
     $self->{_state} = 'running';
     $self->{start_time} = time();
+    $self->{run_pre_start}->($self);
     if (my $pid = fork()) {
 	$self->{pid} = $pid;
 	$self->{pid_last_run} = $pid;
@@ -581,7 +583,7 @@ undef.
 The latest version is available from CPAN and from
 L<https://www.veripool.org/parallel-forker>.
 
-Copyright 2002-2019 by Wilson Snyder.  This package is free software; you
+Copyright 2002-2020 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License
 Version 2.0.
